@@ -1,11 +1,5 @@
 /* $Author: sinnwell $ */
-/* $Date: 2013/01/14 19:10:42 $ */
-/* $Header: /projects/genetics/cvs/cvsroot/haplo.stats/src/haplo_em_pin.c,v 1.18 2013/01/14 19:10:42 sinnwell Exp $ */
-/* $Locker:  $ */
-/*
- * $Log:
-*/
-/*
+/* $Date: 2013/01/14 19:10:42 $ 
 *License: 
 *
 *Copyright 2003 Mayo Foundation for Medical Education and Research. 
@@ -27,7 +21,7 @@
 *
 *Daniel J. Schaid, Ph.D.
 *Division of Biostatistics
-*Harwick Building  Room 775
+*Harwick Building Room 775
 *Mayo Clinic
 *200 First St., SW
 *Rochester, MN 55905
@@ -42,13 +36,12 @@
 #include <math.h>
 #include <string.h>
 #include <limits.h>
-#include <R.h>  
+#include <R.h> 
+#include <R_ext/Error.h>
 #include "haplo_em_pin.h"
 
-
 /* Progressive insertion of loci into haplotypes with EM algorithm */
 
-
 /*************** Global vars ******************************************************/
 
 static int n_loci, *loci_used;               /* used for qsort functions         */   
@@ -105,7 +98,6 @@ void haplo_em_pin(
 
   HAP **hap_list;     /* List of all haplotypes = array of pointers to hap structs */
   HAPUNIQUE **u_hap_list;   /* List of unique haplotypes */
-  HAP *h1, *h2;
 
   /* convert from S vecs to  C structures */
 
@@ -285,29 +277,32 @@ void haplo_em_pin(
 
      } /* end of EM loop */
 
-      if( (*converge)==0){
-        PROBLEM "failed to converge for batch %i after %i iterations", n_batch, n_iter
-		RECOVER(NULL_ENTRY);
-      }
+    if( (*converge)==0){        
+      /* Replaced with call to REprintf for 4.1.x  
+	 PROBLEM "failed to converge for batch %i after %i iterations", n_batch, n_iter
+	 RECOVER(NULL_ENTRY);
+      */
+      REprintf("failed to converge for batch %i after %i iterations", n_batch, n_iter);
+    }
 
 
-       divideKeep(hap_list, n_hap, &len_hap_list);
-       n_hap = len_hap_list;
+    divideKeep(hap_list, n_hap, &len_hap_list);
+    n_hap = len_hap_list;
 
 
-       if(*verbose){
-	 REprintf("\nhap_list after EM and after divideKeep \n\n",n_trim);
-	 write_hap_list(hap_list, n_hap);
-       }
+    if(*verbose){
+      /*REprintf("\nhap_list after EM and after divideKeep \n\n",n_trim);*/
+      write_hap_list(hap_list, n_hap);
+    }
      
    
-      /* update priors, in case haplos were trimmed during posteior calculations */
-
-      hap_prior(n_hap, hap_list, prior, n_u_hap, *min_prior); 
-
-      if(*verbose){
-        if( (*converge)==1){
-          REprintf("\n\nConverged after batch insertion, lnlike = %8.5f, n_iter = %i\n\n", lnlike, n_iter);
+    /* update priors, in case haplos were trimmed during posteior calculations */
+    
+    hap_prior(n_hap, hap_list, prior, n_u_hap, *min_prior); 
+    
+    if(*verbose){
+      if( (*converge)==1){
+	REprintf("\n\nConverged after batch insertion, lnlike = %8.5f, n_iter = %i\n\n", lnlike, n_iter);
         }
       }
 
@@ -1136,7 +1131,7 @@ static int ranAS183_seed(int iseed1, int iseed2, int iseed3)
 
 /***********************************************************************************/
 
-static double ranAS183()
+static double ranAS183(void)
 {
    double u;
 
@@ -1153,7 +1148,10 @@ static void errmsg(char *string){
   /* Function to emulate "stop" of S+ - see page 134, S Programing, by
      Venables and Ripley */
 
-   PROBLEM "%s", string RECOVER(NULL_ENTRY);
+  /* PROBLEM "%s", string RECOVER(NULL_ENTRY);
+     Replace with call to Rf_error for R 4.1.x 
+  */
+  Rf_error(string);
 }
 
 
